/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.schema.export;

import java.io.IOException;
import org.apache.hadoop.conf.Configuration;

public class SchemaWriterFactory {
  public static SchemaWriter getSchemaWriter(Configuration conf) throws IOException {
    try {
      String className = conf.get(SchemaRegistryRepository.SCHEMA_WRITER_IMPL_KEY);
      if (className == null) {
        return new DefaultSchemaWriter();
      }
      Class<SchemaWriter> clazz = (Class<SchemaWriter>) Class.forName(className);
      return clazz.newInstance();
    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
      | ClassCastException e) {
      throw new IOException(e);
    }
  }
}
